#function: Calculate the distance based CCC
CCC_Dist_based<-function(X,Y,R = 1000,tran = "identical",dl = 1e-5){
  n = nrow(X);D_n = ncol(X)
  #Account for zero
  X.transformed = impute.zero(X,n = n,dl)
  Y.transformed = impute.zero(Y,n = n,dl)
  #conduct data transformation
  tranX = switch (tran,
                  "identical" = X,
                  "clr" = compositions::clr(X.transformed))
  tranY = switch (tran,
                  "identical" = Y,
                  "clr" = compositions::clr(Y.transformed))
  #build matrix for further calculation
  tranX_bar = apply(tranX,2,mean.refined)
  tranX_bar_mat = t(matrix(rep(tranX_bar,n),ncol= n))
  tranY_bar = apply(tranY,2,mean.refined)
  tranY_bar_mat = t(matrix(rep(tranY_bar,n),ncol= n))
  tranX1 = cbind(tranX-tranX_bar_mat,tranY-tranY_bar_mat); a = (apply(tranX1,1,Inner)/D_n)
  tranX2 = cbind(tranX,tranX); b = (apply(tranX2,1,Inner)/D_n)
  tranX3 = cbind(tranY,tranY); c = (apply(tranX3,1,Inner)/D_n)
  tranX4 = cbind(tranX-tranX_bar_mat,tranY_bar_mat);tranX5 = cbind(tranX_bar_mat,tranY)
  d = (apply(tranX4,1,Inner)/D_n+apply(tranX5,1,Inner)/D_n)
  mean1<-mean.refined(a);mean2<-mean.refined(b)+mean.refined(c)-2*mean.refined(d)
  if(R==0){
    rhoc.est<-2*mean1/mean2
    W1 = a; W2 = b+c-2*d; sigma_n1 = sd(W1) ; sigma_n2 = sd(W2)
    lambda0 = sigma_n1/sigma_n2; lambda1 = mean1/sigma_n1; lambda2 = mean2/sigma_n2
    w_n.2 = mean.refined((2*(W1-mean1)*lambda0/(lambda2*sigma_n1)-
                            2*(W2-mean2)*lambda0*lambda1/(lambda2^2*sigma_n2))^2)
    rhoc.ase = sqrt(w_n.2/n)
    result<-list(est=rhoc.est,astd.err = rhoc.ase)
    return(result)
  }
  else{
    rhoc.est0<-2*mean1/mean2
    W1 = a; W2 = b+c-2*d; sigma_n1 = sd(W1) ; sigma_n2 = sd(W2)
    lambda0 = sigma_n1/sigma_n2; lambda1 = mean1/sigma_n1; lambda2 = mean2/sigma_n2
    w_n.2 = mean.refined((2*(W1-mean1)*lambda0/(lambda2*sigma_n1)-
                            2*(W2-mean2)*lambda0*lambda1/(lambda2^2*sigma_n2))^2)
    rhoc.ase = sqrt(w_n.2/n)
    #Bootstrap
    rhoc.est = NULL
    for(i in 1:R){
      if(i%%10==0){print(i)}
      tempi = sample(1:n,n,replace = TRUE)
      X.temp = X[tempi,]
      Y.temp = Y[tempi,]
      #Account for zero
      X.transformed = impute.zero(X.temp,n = n,dl)
      Y.transformed = impute.zero(Y.temp,n = n,dl)
      #conduct data transformation
      tranX = switch (tran,
                      "identical" = X.temp,
                      "clr" = compositions::clr(X.transformed))
      tranY = switch (tran,
                      "identical" = Y.temp,
                      "clr" = compositions::clr(Y.transformed))
      #build matrix for further calculation
      tranX_bar = apply(tranX,2,mean.refined)
      tranX_bar_mat = t(matrix(rep(tranX_bar,n),ncol= n))
      tranY_bar = apply(tranY,2,mean.refined)
      tranY_bar_mat = t(matrix(rep(tranY_bar,n),ncol= n))
      tranX1 = cbind(tranX-tranX_bar_mat,tranY-tranY_bar_mat); a = (apply(tranX1,1,Inner))
      tranX2 = cbind(tranX,tranX); b = (apply(tranX2,1,Inner))
      tranX3 = cbind(tranY,tranY); c = (apply(tranX3,1,Inner))
      tranX4 = cbind(tranX-tranX_bar_mat,tranY_bar_mat);tranX5 = cbind(tranX_bar_mat,tranY)
      d = (apply(tranX4,1,Inner)+apply(tranX5,1,Inner))
      mean1<-mean.refined(a);mean2<-mean.refined(b)+mean.refined(c)-2*mean.refined(d)
      rhoc.est<-c(rhoc.est,2*mean1/mean2)
    }
    rhoc.se<-sd(rhoc.est)
    Z.est<-atanh(rhoc.est0)
    Z.se<-rhoc.se/(1-rhoc.est0^2)
    Z.upper = Z.est + 1.96*Z.se;rhoc.upper = tanh(Z.upper)
    Z.lower = Z.est - 1.96*Z.se;rhoc.lower = tanh(Z.lower)
    result<-list(est=rhoc.est0,astd.err = rhoc.ase,std.err=rhoc.se,lower=rhoc.lower,upper = rhoc.upper,boot.est = rhoc.est)
    return(result)
  }}
