\name{CCC_Dist}
\alias{CCC_Dist}
\title{
Distance Based CCC to Assess the Reproducibility
}
\description{
This function present the output for the distance based CCC to assess the agreement.
}
\usage{
CCC_Dist(X,Y,method,R = 0,dl = 1e-5)
}
\arguments{
  \item{X}{ A matrix, representing the first set of measurements.}
  \item{Y}{ A matrix, representing the second set of measurements.}
  \item{method}{ Indicate the distance based method used. If method = "Euclidean", then the Euclidean distance based CCC is calculated; if method = "Euclidean sub union", then the Euclidean distance based CCC is calculated after removing the union set zeros for the two measurements;if method = "Aitchison", then the Aitchison distance based CCC is calculated; if method = "Aitchison sub union", then the Aitchison distance based CCC is calculated after removing the union set zeros for the two measurements;}
  \item{R}{ Default to be 0. If R = 0, then only the concordance correlation coefficient is returned; else R would represent for the number of bootstrap samples used to derive the standard error and confidence interval.}
  \item{dl}{ The arguments for delta/D, which is a small value added to all zeros.}
}
\details{
If R = 0, the output will only include the analytical value(s) for the concordance correlation coefficient. Otherwise, if method = "Euclidean" or "Aitchison", then the output will be a list including the estimated CCC, analytical standard error, bootstrap standard error derived by bootstrap method, lower and upper confidence intervals, and a vector saving the estimated values for all bootstrap samples;if method = "Euclidean sub union" or "Aitchison sub union", then the output will be a list including the estimated CCC, bootstrap standard error derived by bootstrap method, lower and upper confidence intervals, and a vector saving the estimated values for all bootstrap samples;
}
\value{
  \item{est}{ Estimated value for the concordance correlation coefficient.}
  \item{astd.err}{ Analytical value for the standard error of the concordance correlation coefficient.}
  \item{std.err}{ Standard error of the concordance correlation coefficient derived by bootstrap method.}
  \item{lower}{ The lower confidence interval of the concordance correlation coefficient}
  \item{upper}{ The upper confidence interval of the concordance correlation coefficient}
  \item{boot.est}{ A vector saving the concordance correlation coefficient calculated for all bootstrap samples}
}
\examples{
data(X)
data(Y)
CCC_Dist(X, Y, method = "Euclidean")
}
\keyword{Distance based CCC}
